/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *    Brutus header file for Brutus string utility functions.
 *    Copyright (C) 2005-2007 OMC Denmark ApS.
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *    MA 02111-1307 USA
 */

#ifndef _BRUTUS_STRING_H_
#define _BRUTUS_STRING_H_

#include <glib/gtypes.h>

G_BEGIN_DECLS

/*
 * Will remove any trailing character 't' from 'str'
 */
extern void brutus_strip_trailing_char(const char t,
				       char *str);

/*
 * Will check a string for conversion into an "bits" bit wide
 * unsigned long long number. Returns FALSE on error.
 */
extern gboolean brutus_get_xbit_number(const guint8 bits,
				       const char *num_str,
				       guint64 *ul);

/*
 * Will realloc and strcat src to *dest, freeing *dest if
 * not successfull. Returns a pointer to the longer string.
 */
extern char *brutus_append_string(char **dest,
				  const char *src);

/* The return value must be freeed by the caller. */
extern char *brutus_to_string(const char *fmt,
			      ...);

/* Composite of append_string() and to_string() */
extern void brutus_append_to_string(char **dest,
				    const char *fmt,
				    ...);

/* Creates an ORBInitRef string suitable for ORBit2 */
extern char *brutus_build_init_ref_opt(const char *init_ref,
				       const char *ior_table_key,
				       const char *server_host,
				       const guint16 server_port);

extern char *brutus_build_corbaloc_string(const char *brutus_server,
					  const char *ior_table_key,
					  const guint16 brutus_port);
/*
 * Will check if the two paths share the same parent folder.
 *
 * The last element of any path (in this case "foobar") must
 * not be the empty string.
 *
 *
 " These paths are siblings (returns TRUE):
 *
 * "/foo/bar/foobar//"
 * "/foo/bar/foobar/"
 * "/foo/bar/foobar"
 *
 *
 " These paths are not siblings (returns FALSE):
 *
 * "//foo/bar/foobar"
 * "//foo/bar//foobar"
 * "/foo/bar/foobar"
 *
 */
extern gboolean brutus_is_siblings(const char *path_a,
				   const char *path_b);

/*
 * 'str' is a null terminated string of the form:
 *
 * "[OPTIONAL WHITESPACE]word_1<WHITESPACE>word_2<WHITESPACE> ...word_n"
 *
 * The function will return a pointer to 'w' in word_2 
 * or NULL if no 'word_2' exists.
 */
extern const char *brutus_next_word(const char *str);

G_END_DECLS

#endif /* _BRUTUS_STRING_H_ */
