/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *    Brutus header file for Brutus utility functions.
 *    Copyright (C) 2005-2007 OMC Denmark ApS.
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *    MA 02111-1307 USA
 */

#ifndef _BRUTUS_UTIL_H_
#define _BRUTUS_UTIL_H_

#include <glib.h>
#include <libecal/e-cal.h>

#include <idl_output/BrutusLogOn.h>
#include <idl_output/IMAPISession.h>
#include <session/brutus-proxy.h>
#include <session/brutusd-util.h>
#include <servant_impl/BrutusCheck.h>
#include "brutus.h"

G_BEGIN_DECLS

#define BRUTUS_SERVER_REQ_VERSION_STRING "0.9.38"

enum E_SOURCE_BRUTUS_TYPE
{
	E_SOURCE_BRUTUS_UNKNOWN         = 0,
	E_SOURCE_BRUTUS_CALENDAR        = 1,
	E_SOURCE_BRUTUS_TASKS           = 2,
	E_SOURCE_BRUTUS_NOTES           = 3,
	E_SOURCE_BRUTUS_ADDRESSBOOK_PAB = 4, // Personal Address Book
	E_SOURCE_BRUTUS_ADDRESSBOOK_GAL = 5  // Global Address List
};

enum E_BRUTUS_DAEMON
{	E_BRUTUS_SESSION_DAEMON,
	E_BRUTUS_LOG_DAEMON,
	E_BRUTUS_KEYRING_DAEMON
};

/*
 * Returns TRUE if the version of the remote Brutus Server is
 * supported.
 */
extern gboolean brutus_server_version_OK(int major,
					 int minor,
					 int micro,
					 int release_tag);

/*
 * Both of these are for use in g_list_foreach() and g_slist_foreach()
 */
extern void brutus_for_each_free(gpointer data,
				 gpointer user_data);

extern void brutus_for_each_g_free(gpointer data,
				   gpointer user_data);

/*
 * time_zone_offset: offset from GMT in minutes - east is negative, west
 * is positive
 *
 * Will return 100 if time_zone_offset is -60.
 * Will return 130 if time_zone_offset is -90.
 */
extern int brutus_timezone_to_gmt_offset(long time_zone_offset);

/*
 * This will add a Brutus ECal source to gconf
 */
extern gboolean brutus_add_account(const enum E_SOURCE_BRUTUS_TYPE e_type,
				   const char *account_name,
				   const char *mapi_profile,
				   const char *exchange_server,
				   const char *windows_user,
				   const char *exchange_mailbox,
				   const char *exchange_mailbox_dn,
				   const char *exchange_mailbox_email,
				   const char *windows_domain,
				   const char *brutus_server,
				   const guint16 brutus_port,
				   const gboolean expect_other_clients,
				   int auto_check_timeout); // in minutes

extern void brutus_remove_account(const enum E_SOURCE_BRUTUS_TYPE e_type,
				  const char *account_name,
				  const char *mapi_profile);

extern gboolean brutus_logon_loop(BRUTUS_BrutusLogOn brutus_logon,
				  BRUTUS_BrutusCheck lifeline,
				  BRUTUS_IMAPISession *mapi_session,
				  CORBA_unsigned_long *instance_id,
				  char **mapi_profile,
				  const char *prompt,
				  const char *err_prompt,
				  const char *windows_user,
				  const char *windows_domain,
				  const char *exchange_mailbox,
				  const char *exchange_mailbox_dn,
				  const char *exchange_mailbox_email,
				  const char *exchange_server);

/*
 * Will get the stringified MD5 digest of 'str'
 */
extern void brutus_get_digest_str(const char *str,
				  digest_str_t digest_str);

/*
 * Caller must g_free() the return value
 */
extern gchar *brutus_strip_trailing_and_leading_whitespace(const char *str);

/*
 * Will generate a UUID string
 */
extern gboolean brutus_get_random_uuid(uuid_str_t uuid_str);


/* will free the content of lifeline */
extern void brutus_free_lifeline(BRUTUS_BrutusProxy proxy,
				 PortableServer_POA poa,
				 struct BrutusCheckProxy *lifeline);

/* will free the content of base_class */
extern void brutus_base_class_free(BrutusBaseClass *base_class);

/* will init the content of base_class */
extern void brutus_base_class_init(BrutusBaseClass *base_class);

/* will start the specified daemon process - returns the retval of system(3) */
extern int brutus_start_daemon(const enum E_BRUTUS_DAEMON which);

/* will return the process id for the specified daemon process or (-1) if not found */
extern pid_t brutus_get_daemon_pid(const enum E_BRUTUS_DAEMON which);

/* will send SIGUSR2 to the specified daemon process */
extern void brutus_restart_daemon(const enum E_BRUTUS_DAEMON which);

/* will send SIGKILL to the specified daemon process */
extern void brutus_kill_daemon(const enum E_BRUTUS_DAEMON which);

/* sledgehammer approach... */
extern void brutus_restart_proxy(CORBA_ORB orb,
				 PortableServer_POA root_poa,
				 gboolean use_local_proxy,
				 BRUTUS_BrutusProxy *proxy,
				 struct BrutusCheckProxy *lifeline);
/* simple type conversion  */
extern enum E_SOURCE_BRUTUS_TYPE brutus_int_to_e_type(int i_rep);

/* simple type conversion  */
extern unsigned int brutus_e_type_to_unsigned_int(enum E_SOURCE_BRUTUS_TYPE e_rep);

/* converts '/' and ':' to '_' */
extern gchar* brutus_mangle_uri(const gchar *uri);

/* Returns TRUE if the base_class eare likely connected to the server */
extern gboolean brutus_is_likely_connected(BrutusBaseClass *base_class);

/* Sets the likely_connected property */
extern void brutus_set_likely_connected(BrutusBaseClass *base_class,
					gboolean likely_connected);

/* Return the server reported UTC time - or 0 (zero) when failed */
extern time_t brutus_get_server_utc_time(const char *brutus_server,
					 BRUTUS_IMAPISession mapi_session,
					 const char *exchange_server);
/*
 * Will search for and delete 'str' in the pointer array of strings 'arr'
 */
extern void brutus_g_ptr_array_find_and_delete_string(GPtrArray *arr,
						      char *str);

G_END_DECLS

#endif /* _BRUTUS_UTIL_H_ */
